<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
  <context>
    <name>CmdDrawingAnnotation</name>
    <message>
      <location filename="../../Command.cpp" line="+389"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Annotation</source>
      <translation>&amp;Adnotacja</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts an Annotation view in the active drawing</source>
      <translation>Wstawia widok adnotacji w aktywnym rysunku</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingClip</name>
    <message>
      <location line="+41"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Clip</source>
      <translation>&amp; Klip</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts a clip group in the active drawing</source>
      <translation>Wstawia grupę klipu do aktywnego rysunku</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location line="+91"/>
      <source>File</source>
      <translation>Plik</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Export page...</source>
      <translation>&amp;Eksportuj stronę...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Export a page to an SVG file</source>
      <translation>Eksport strony do pliku SVG</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <location line="-314"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Insert new A3 landscape drawing</source>
      <translation>Wstaw formatkę A3 poziomo</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewPage</name>
    <message>
      <location line="-133"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Insert new drawing</source>
      <translation>Wstaw nowy rysunek</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <location line="+166"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert view in drawing</source>
      <translation>Wstaw widok w rysunku</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>Wstaw nowy widok części w aktywnym rysunku</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <location line="-202"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open SVG...</source>
      <translation>Otwórz SVG...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open a scalable vector graphic</source>
      <translation>Otwórz skalowalną grafikę wektorową</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpenBrowserView</name>
    <message>
      <location line="+294"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open &amp;browser view</source>
      <translation>Otwórz &amp;widok przeglądania</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Opens the selected page in a browser view</source>
      <translation>Otwiera wybraną stronę w przeglądarce</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOrthoViews</name>
    <message>
      <location line="-49"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert orthographic views</source>
      <translation>Wstaw widoki ortogonalne</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert an orthographic projection of a part in the active drawing</source>
      <translation>Wstaw rzut ortogonalny części aktywnego rysunku</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingProjectShape</name>
    <message>
      <location line="+271"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Project shape...</source>
      <translation>Rzut obwiedni...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Project shape onto a user-defined plane</source>
      <translation>Rzut obwiedni na płaszczyznę zdefiniowaną przez użytkownika</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSymbol</name>
    <message>
      <location line="-107"/>
      <source>Drawing</source>
      <translation type="unfinished">Rysunek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Symbol</source>
      <translation type="unfinished">&amp;Symbol</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts a symbol from a svg file in the active drawing</source>
      <translation type="unfinished">Inserts a symbol from a svg file in the active drawing</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location filename="../../DrawingView.cpp" line="+207"/>
      <source>&amp;Background</source>
      <translation>&amp;Tło</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>&amp;Outline</source>
      <translation>&amp;Zarys</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>&amp;Native</source>
      <translation>&amp;Wbudowany</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;OpenGL</source>
      <translation>OpenGL</translation>
    </message>
    <message>
      <location line="+3"/>
      <source>&amp;Image</source>
      <translation>&amp;Obraz</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;High Quality Antialiasing</source>
      <translation>&amp;Wygładzanie wysokiej jakości</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Open SVG File</source>
      <translation>Otwórz plik SVG</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not open file '%1'.</source>
      <translation>Nie można otworzyć pliku '%1'.</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>&amp;Renderer</source>
      <translation>&amp;Renderer</translation>
    </message>
    <message>
      <location line="+55"/>
      <source>Export PDF</source>
      <translation>Eksport PDF</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>PDF file (*.pdf)</source>
      <translation>Plik PDF (*. pdf)</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>Page sizes</source>
      <translation>Rozmiary stron</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>A0</source>
      <translation>A0</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskOrthoViews</name>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="+26"/>
      <source>Orthographic Projection</source>
      <translation>Rzutowanie ortogonalne</translation>
    </message>
    <message>
      <location line="+20"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+31"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+60"/>
      <source>Right click for axonometric settings</source>
      <translation type="unfinished">Right click for axonometric settings</translation>
    </message>
    <message>
      <location line="+106"/>
      <source>Top left x / y</source>
      <translation type="unfinished">Top left x / y</translation>
    </message>
    <message>
      <location line="+48"/>
      <source>Spacing dx / dy   </source>
      <translation type="unfinished">Spacing dx / dy   </translation>
    </message>
    <message>
      <location line="+71"/>
      <source> Axis out and right</source>
      <translation type="unfinished"> Axis out and right</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> Vertical tilt</source>
      <translation type="unfinished"> Vertical tilt</translation>
    </message>
    <message>
      <location line="+11"/>
      <location line="+200"/>
      <source>X +ve</source>
      <translation type="unfinished">X +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+75"/>
      <location line="+125"/>
      <source>Y +ve</source>
      <translation type="unfinished">Y +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+75"/>
      <location line="+125"/>
      <source>Z +ve</source>
      <translation type="unfinished">Z +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+200"/>
      <source>X -ve</source>
      <translation type="unfinished">X -ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+70"/>
      <location line="+130"/>
      <source>Y -ve</source>
      <translation type="unfinished">Y -ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+70"/>
      <location line="+130"/>
      <source>Z -ve</source>
      <translation type="unfinished">Z -ve</translation>
    </message>
    <message>
      <location line="-188"/>
      <source>Isometric</source>
      <translation type="unfinished">Isometric</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Dimetric</source>
      <translation type="unfinished">Dimetric</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Trimetric</source>
      <translation type="unfinished">Trimetric</translation>
    </message>
    <message>
      <location line="+8"/>
      <source> Scale</source>
      <translation type="unfinished"> Scale</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> View projection   </source>
      <translation type="unfinished"> View projection   </translation>
    </message>
    <message>
      <location line="+7"/>
      <source> Axis aligned up</source>
      <translation type="unfinished"> Axis aligned up</translation>
    </message>
    <message>
      <location line="+41"/>
      <location line="+23"/>
      <source>Flip</source>
      <translation type="unfinished">Flip</translation>
    </message>
    <message>
      <location line="-10"/>
      <source> Trimetric</source>
      <translation type="unfinished"> Trimetric</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Projection</source>
      <translation>Rzut</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Third Angle</source>
      <translation>Kąt trzeci</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>First Angle</source>
      <translation>Kąt pierwszy</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>View from:</source>
      <translation type="unfinished">View from:</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>Axis aligned right:</source>
      <translation type="unfinished">Axis aligned right:</translation>
    </message>
    <message>
      <source>Primary View</source>
      <translation type="obsolete">Widok podstawowy</translation>
    </message>
    <message>
      <source>Front</source>
      <translation type="obsolete">Przód</translation>
    </message>
    <message>
      <source>Right</source>
      <translation type="obsolete">Prawo</translation>
    </message>
    <message>
      <source>Back</source>
      <translation type="obsolete">Wstecz</translation>
    </message>
    <message>
      <source>Left</source>
      <translation type="obsolete">Lewa</translation>
    </message>
    <message>
      <source>Top</source>
      <translation type="obsolete">Góra</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation type="obsolete">U dołu</translation>
    </message>
    <message>
      <source>- Rotate</source>
      <translation type="obsolete">-Obrót</translation>
    </message>
    <message>
      <source>90</source>
      <translation type="obsolete">90</translation>
    </message>
    <message>
      <source>180</source>
      <translation type="obsolete">180</translation>
    </message>
    <message>
      <source>270</source>
      <translation type="obsolete">270</translation>
    </message>
    <message>
      <location line="-514"/>
      <source>Primary view</source>
      <translation>Widok główny</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>Secondary Views</source>
      <translation>Inne Widoki</translation>
    </message>
    <message>
      <location line="+72"/>
      <source>General</source>
      <translation>Ogólne</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Auto scale / position</source>
      <translation>Auto skala / pozycja</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Scale</source>
      <translation>Skala</translation>
    </message>
    <message>
      <source>Primary x / y</source>
      <translation type="obsolete">Podstawowe x / y</translation>
    </message>
    <message>
      <source>Secondary dx / dy</source>
      <translation type="obsolete">Wtórne dx / dy</translation>
    </message>
    <message>
      <location line="+125"/>
      <source>Show hidden</source>
      <translation>Pokaż ukryte</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Show smooth</source>
      <translation>Pokaż gładkie</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Axonometric</source>
      <translation>Aksonometryczny</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskProjection</name>
    <message>
      <location filename="../../TaskDialog.cpp" line="+49"/>
      <source>Visible sharp edges</source>
      <translation>Widoczne ostre krawędzie</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible smooth edges</source>
      <translation>Widoczne gładkie krawędzie</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible sewn edges</source>
      <translation>Widoczne wszyte krawędzie</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible outline edges</source>
      <translation>Widoczny obrys krawędzi</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible isoparameters</source>
      <translation>Widoczne izoparametry</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden sharp edges</source>
      <translation>Ukryte ostre krawędzie</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden smooth edges</source>
      <translation>Ukryte gładkie krawędzie</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden sewn edges</source>
      <translation>Ukryte wszyte krawędzie</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden outline edges</source>
      <translation>Ukryty obrys krawędzi</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden isoparameters</source>
      <translation>Ukryte krzywe isoparametryczne</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Project shapes</source>
      <translation>Rzutowanie obwiedni</translation>
    </message>
  </context>
  <context>
    <name>Drawing_NewPage</name>
    <message>
      <source>A0 landscape</source>
      <translation type="obsolete">A0 poziomo</translation>
    </message>
    <message>
      <source>Insert new A0 landscape drawing</source>
      <translation type="obsolete">Wstaw formatkę A0 poziomo</translation>
    </message>
    <message>
      <source>A1 landscape</source>
      <translation type="obsolete">A1 poziomo</translation>
    </message>
    <message>
      <source>Insert new A1 landscape drawing</source>
      <translation type="obsolete">Wstaw formatkę A1 poziomo</translation>
    </message>
    <message>
      <source>A2 landscape</source>
      <translation type="obsolete">A2 poziomo</translation>
    </message>
    <message>
      <source>Insert new A2 landscape drawing</source>
      <translation type="obsolete">Wstaw formatkę A3 poziomo</translation>
    </message>
    <message>
      <source>A3 landscape</source>
      <translation type="obsolete">A3 poziomo</translation>
    </message>
    <message>
      <source>Insert new A3 landscape drawing</source>
      <translation type="obsolete">Wstaw formatkę A3 poziomo</translation>
    </message>
    <message>
      <source>A4 landscape</source>
      <translation type="obsolete">A4 poziomo</translation>
    </message>
    <message>
      <source>Insert new A4 landscape drawing</source>
      <translation type="obsolete">Wstaw formatkę A4 poziomo</translation>
    </message>
    <message>
      <source>Insert new A%1 landscape drawing</source>
      <translation type="obsolete">Wstaw nowy rysunek A%1 Poziomy</translation>
    </message>
    <message>
      <source>A%1 landscape</source>
      <translation type="obsolete">A%1 Poziomy</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-298"/>
      <source>Landscape</source>
      <translation type="unfinished">Landscape</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Portrait</source>
      <translation type="unfinished">Portrait</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>%1%2 %3</source>
      <translation type="unfinished">%1%2 %3</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Insert new %1%2 %3 drawing</source>
      <translation type="unfinished">Insert new %1%2 %3 drawing</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location line="-124"/>
      <location line="+426"/>
      <source>Choose an SVG file to open</source>
      <translation>Wybierz plik SVG do otwarcia</translation>
    </message>
    <message>
      <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
      <location line="+30"/>
      <location filename="../../ViewProviderPage.cpp" line="+139"/>
      <source>Drawing viewer</source>
      <translation>Podgląd rysunku</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-425"/>
      <location line="+426"/>
      <source>Scalable Vector Graphics (*.svg *.svgz)</source>
      <translation>Skalowalna Grafika Wektorowa (*.svg *.svgz)</translation>
    </message>
    <message>
      <location line="-227"/>
      <location line="+51"/>
      <location line="+45"/>
      <location line="+177"/>
      <source>Wrong selection</source>
      <translation>Niewłaściwy wybór</translation>
    </message>
    <message>
      <location line="-272"/>
      <location line="+51"/>
      <source>Select a Part object.</source>
      <translation>Wybierz stronę.</translation>
    </message>
    <message>
      <location line="-45"/>
      <location line="+51"/>
      <location line="+76"/>
      <location line="+45"/>
      <location line="+42"/>
      <source>No page to insert</source>
      <translation>Brak strony do wstawienia.</translation>
    </message>
    <message>
      <location line="-213"/>
      <location line="+127"/>
      <location line="+45"/>
      <location line="+42"/>
      <source>Create a page to insert.</source>
      <translation>Utwórz stronę do wstawienia.</translation>
    </message>
    <message>
      <location line="-163"/>
      <source>Create a page to insert views into.</source>
      <translation>Utwórz stronę do wstawienia widoków.</translation>
    </message>
    <message>
      <location line="+38"/>
      <location line="+177"/>
      <source>Select one Page object.</source>
      <translation>Wybierz jedną Stronę</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>SVG(*.svg)</source>
      <translation>SVG (*. svg)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>All Files (*.*)</source>
      <translation>Wszystkie pliki (*.*)</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Export page</source>
      <translation>Wyślij stronę</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPage.cpp" line="-27"/>
      <source>Show drawing</source>
      <translation>Pokaż rysunek</translation>
    </message>
    <message>
      <source>Front</source>
      <translation type="obsolete">Przód</translation>
    </message>
    <message>
      <source>Back</source>
      <translation type="obsolete">Wstecz</translation>
    </message>
    <message>
      <source>Right</source>
      <translation type="obsolete">Prawo</translation>
    </message>
    <message>
      <source>Left</source>
      <translation type="obsolete">Lewa</translation>
    </message>
    <message>
      <source>Top</source>
      <translation type="obsolete">Góra</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation type="obsolete">U dołu</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
      <location line="+908"/>
      <source>Make axonometric...</source>
      <translation type="unfinished">Make axonometric...</translation>
    </message>
    <message>
      <location line="-907"/>
      <location line="+908"/>
      <source>Edit axonometric settings...</source>
      <translation type="unfinished">Edit axonometric settings...</translation>
    </message>
    <message>
      <location line="-907"/>
      <location line="+908"/>
      <source>Make orthographic</source>
      <translation type="unfinished">Make orthographic</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Drawing</source>
      <translation>Rysunek</translation>
    </message>
  </context>
</TS>
